databeta_na: Synthetic Data with Missing Values for Small Area Estimation

databeta_naR Documentation

Synthetic Data with Missing Values for Small Area Estimation

Description

A synthetic dataset identical to databeta, but contains 5 missing values (NA) in the variable of interest (y) to demonstrate the prediction capability of the models for non-sampled areas.

Usage

data(databeta_na)

Format

A data frame with 36 rows and 6 columns:

domain

Area ID/name

y

Direct estimates of the proportion/variable of interest (0 < y < 1). Contains NA values.

x1

Auxiliary variable 1

x2

Auxiliary variable 2

n_i

Sample size for each area

deff

Survey design effect for each area


saeHB.Spatial.Beta documentation built on July 1, 2026, 5:07 p.m.