weight_mat: Row-Standardized Spatial Weight Matrix

weight_matR Documentation

Row-Standardized Spatial Weight Matrix

Description

A row-standardized proximity matrix (W) generated from a 6x6 regular grid using Queen contiguity. This matrix is mathematically suitable for the Spatial Simultaneous Autoregressive (SAR) model and Moran's I test.

Usage

data(weight_mat)

Format

A 36 x 36 numeric matrix. The values are numbers in the interval [0,1] representing the proximity of the row and column areas. The sum of the values in each row is exactly 1.


saeHB.Spatial.Beta documentation built on July 1, 2026, 5:07 p.m.