| databeta_na | R Documentation |
A synthetic dataset identical to databeta, but contains 5 missing values (NA) in the
variable of interest (y) to demonstrate the prediction capability of the models for non-sampled areas.
data(databeta_na)
A data frame with 36 rows and 6 columns:
Area ID/name
Direct estimates of the proportion/variable of interest (0 < y < 1). Contains NA values.
Auxiliary variable 1
Auxiliary variable 2
Sample size for each area
Survey design effect for each area
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.