| weight_mat | R Documentation |
A row-standardized proximity matrix (W) generated from a 6x6 regular grid using Queen contiguity.
This matrix is mathematically suitable for the Spatial Simultaneous Autoregressive (SAR) model and Moran's I test.
data(weight_mat)
A 36 x 36 numeric matrix. The values are numbers in the interval [0,1] representing the proximity of the row and column areas. The sum of the values in each row is exactly 1.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.